@@ -7,7 +7,7 @@
 */
 
 /* .Fortran calls */
-extern void F77_NAME(front41)( int *imArg, int *ipcArg, int *iceptArg,
+extern void F77_NAME(front41)( int *imArg, int *ipcArg,
    int *nnArg, int *ntArg, int *nobArg, int *nbArg, int *nmuArg, int *netaArg,
    int *iprintArg, int *indicArg, double *tolArg, double *tol2Arg, double *bignumArg,
    double *step1Arg, int *igrid2Arg, double *gridnoArg, int *maxitArg, double *bmuArg,
@@ -18,7 +18,7 @@ extern void F77_NAME(front41)( int *imArg, int *ipcArg, int *iceptArg,
    int *nIter, int *icodeArg, int *nfunctArg );
 
 static const R_FortranMethodDef FortranEntries[] = {
-    {"front41", (DL_FUNC) &F77_NAME(front41), 38},
+    {"front41", (DL_FUNC) &F77_NAME(front41), 37},
     {NULL, NULL, 0}
 };
 
