@@ -11,25 +11,25 @@ riceProdPhil$cost <- riceProdPhil$LABOR * riceProdPhil$LABORP +
 ## front41Data
 a1 <- sfa( log( output ) ~ log( capital ) + log( labour ),
    ineffDecrease = FALSE, data = front41Data )
-summary( a1, farrell = FALSE )
+print( summary( a1, effMinusU = FALSE ), digits = 1 )
 lrtest( a1 )
 
 ## front41Data, truncNorm
 a2 <- sfa( log( output ) ~ log( capital ) + log( labour ),
    ineffDecrease = FALSE, truncNorm = TRUE, data = front41Data )
-summary( a2, farrell = FALSE )
+print( summary( a2, effMinusU = FALSE ), digits = 1 )
 lrtest( a2 )
 
 ## riceProdPhil
 b1 <- sfa( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ),
    ineffDecrease = FALSE, data = riceProdPhil )
-summary( b1, farrell = FALSE )
+print( summary( b1, effMinusU = FALSE ), digits = 1 )
 lrtest( b1 )
 
 ## riceProdPhil, truncNorm
 b2 <- sfa( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ),
    ineffDecrease = FALSE, truncNorm = TRUE, data = riceProdPhil )
-summary( b2, farrell = FALSE )
+print( summary( b2, effMinusU = FALSE ), digits = 1 )
 lrtest( b2 )
 
 
@@ -37,11 +37,11 @@ lrtest( b2 )
 ## riceProdPhil
 d1 <- sfa( log( cost ) ~ log( PROD ) + log( AREA ) + log( LABORP ) +
    log( NPKP ), data = riceProdPhil )
-summary( d1 )
+print( summary( d1 ), digits = 1 )
 lrtest( d1 )
 
 ## riceProdPhil, truncNorm
 d2 <- sfa( log( cost ) ~ log( PROD ) + log( AREA ) + log( LABORP ) +
    log( NPKP ), truncNorm = TRUE, data = riceProdPhil )
-summary( d2 )
+print( summary( d2 ), digits = 1 )
 lrtest( d2 )
